using BPA.SAAS.Manage.Application.System.Dtos;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.SAAS.Manage.Application.System.Interface
{
    public interface IMenuService
    {
        Task<List<MenuTreeDtoOutput>> GetMenuTreePage(MenuTreeSearchDtoInput input);
        Task<bool> Add(MenuDtoInput input);
        Task<bool> Update(MenuDtoInput input);
        Task<bool> Delete(List<string> input);
        Task<List<MenuTreeOutput>> MenuTree();
        Task<List<MenuTreeOutput>> MenuTree(string GetType);
        Task<List<MenuTreeOutput>> MenuParmyTree(string GetType, string type);
        Task<List<MenuRouteDtoOutput>> DymicMenuTree(int type);
        Task<bool> Enable(string Id);
        Task<bool> Disable(string Id);
    }
}
